@@ -1,7 +1,7 @@
 /* baumbrl.h
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,11 +19,15 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef _BAUMBRL_H
-#define _BAUMBRL_H			
+#ifndef __BAUMBRL_H__
+#define __BAUMBRL_H__			
 
+#include <glib.h>
 #include "braille.h"
 
-int baum_brl_open_device (char* DeviceName, short Port, BRL_DEV_CALLBACK DeviceCallback, BRL_DEVICE *Device);
+gint baum_brl_open_device (gchar          *device_name, 
+			  gchar           *port,
+			  BRLDevCallback  device_callback,
+			  BRLDevice       *device);
 
 #endif
