@@ -1,7 +1,7 @@
 /* brlxml.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -730,9 +730,10 @@ brl_start_element (void            *ctx,
 			/* fprintf (stderr, "\n attr_val; %s", *attrs); */
 			if (g_strcasecmp ((gchar*)*attrs, "mode") == 0)
 			{
-			    ++attrs;
 			    gint16 new_offset = 0;
 			    gshort sign = 1;
+
+			    ++attrs;
 					
 			    attr_val = g_strdup ((gchar*)*attrs);
 			    tattr_val = g_strdup (attr_val);
@@ -1061,7 +1062,7 @@ brl_braille_events (BRLEventCode event_code, BRLEventData *event_data)
 
 gint
 brl_xml_init (gchar           *device_name,
-	      gint            port,
+	      gchar           *port,
 	      BRLXmlInputProc input_callback_proc)
 {
     gint rv = 1;
